@@ -18,9 +18,9 @@ rpm --checksig kernel-2.6.16-76.55vl4.src.rpm || die "Can't verify signature."
 rpm -ivh kernel-2.6.16-76.55vl4.src.rpm || die "Can't install source package."
 
 cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.2-20100804.tar.gz ]
+if [ ! -r ccs-patch-1.7.3-20110903.tar.gz ]
 then
-    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20100804.tar.gz || die "Can't download patch."
+    wget -O ccs-patch-1.7.3-20110903.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.3-20110903.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -33,7 +33,7 @@ patch << "EOF" || die "Can't patch spec file."
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
 -%define release 76.55%{_dist_release}
-+%define release 76.55%{_dist_release}_tomoyo_1.7.2p2
++%define release 76.55%{_dist_release}_tomoyo_1.7.3p1
  
  %define make_target bzImage
  
@@ -61,7 +61,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.2-20100804.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.7.3-20110903.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.16-vine-linux-4.2.diff
 +
  cp %{SOURCE10} Documentation/
