@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/condition.c
  *
- * Copyright (C) 2005-2010  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.7.2+   2010/06/09
+ * Version: 1.7.3   2011/04/01
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -263,24 +263,6 @@ static bool ccs_scan_exec_realpath(struct file *file,
 	return result == match;
 }
 
-static bool ccs_parse_name_union_quoted(char *filename,
-					struct ccs_name_union *ptr)
-{
-	bool result;
-	char *cp = NULL;
-	if (*filename == '"') {
-		cp = filename + strlen(filename) - 1;
-		if (*cp != '"')
-			return false;
-		*cp = '\0';
-		filename++;
-	}
-	result = ccs_parse_name_union(filename, ptr);
-	if (cp)
-		*cp = '"';
-	return result;
-}
-
 /**
  * ccs_get_dqword - ccs_get_name() for a quoted string.
  *
@@ -308,6 +290,16 @@ static const struct ccs_path_info *ccs_get_dqword(char *start)
 	return ccs_get_name(start);
 }
 
+static bool ccs_parse_name_union_quoted(char *filename,
+					struct ccs_name_union *ptr)
+{
+	if (*filename == '@')
+		return ccs_parse_name_union(filename, ptr);
+	ptr->is_group = false;
+	ptr->filename = ccs_get_dqword(filename);
+	return ptr->filename != NULL;
+}
+
 /**
  * ccs_parse_argv - Parse an argv[] condition part.
  *
